==> haskell-strict-list-0.1.7.6-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-KIKbPgHg936A0u79pGFPnr
key:                  strict-list-0.1.7.6-KIKbPgHg936A0u79pGFPnr
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  e41b21cd5934c3932d4b25c26be5f8a3
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-KIKbPgHg936A0u79pGFPnr
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.5.0-46ofdJt9DgFJv5hpm4ccL9
    semigroupoids-6.0.1-3CUWeXYcv8xJ5tqbj8MWiW

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-list-0.1.7.6-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-EQTuyxAyrk5Bw2wP3cdrb
key:                  strict-list-0.1.7.6-EQTuyxAyrk5Bw2wP3cdrb
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  afdb1fac6c60f11dd65639e45ee7f7e1
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-EQTuyxAyrk5Bw2wP3cdrb
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.6.0-2vEivDIcaMF9mfkC7wRjoU
    semigroupoids-6.0.1-20Td3TsVKPT7ywapKS1MKw

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
